Metadata description for 'Bilingual Glossary German-English with Probabilities'

Bilingual Glossary German-English with Probabilities

This glossary contains German entries with multiple English transfers, 22.000 transfers in total. It is lemma-based, annotated with part-of-speech information and with several probabilities, to support transfer selection for multiple translation possibilities. It is the result of PANACEA research.

# BASIC INFORMATION

## Identification Information

- resourceName: Bilingual Glossary German-English with Probabilities
- description: This glossary contains German entries with multiple English transfers, 22.000 transfers in total. It is lemma-based, annotated with part-of-speech information and with several probabilities, to support transfer selection for multiple translation possibilities. It is the result of PANACEA research.
- resourceShortName: Glossary DE-EN_prob
- metaShareId: NOT_DEFINED_FOR_V2

# ADMINISTRATIVE INFORMATION

## Contact Person(s)

- surname: Thurmair
- givenName: Gregor
- communicationInfo:

- email: info@linguatec.de
- address: Gottfried-Keller-Str. 12
- zipCode: 81245
- city: Munich
- country: Germany

- affiliation:

- organizationName: Linguatec GmbH
- organizationShortName: Linguatec GmbH
- communicationInfo:

- email: info@linguatec.de
- address: Gottfried-Keller-Str. 12
- zipCode: 81245
- city: Munich
- country: Germany
- telephoneNumber: +49 0 89 896664-0
- faxNumber: +49 0 89 88919933

- surname: Aleksić
- givenName: Vera
- communicationInfo:

- email: info@linguatec.de
- address: Gottfried-Keller-Str. 12
- zipCode: 81245
- city: Munich
- country: Germany

- affiliation:

- organizationName: Linguatec GmbH
- organizationShortName: Linguatec GmbH
- communicationInfo:

- email: info@linguatec.de
- address: Gottfried-Keller-Str. 12
- zipCode: 81245
- city: Munich
- country: Germany
- telephoneNumber: +49 0 89 896664-0
- faxNumber: +49 0 89 88919933

## Distribution Information

- Availability type: available-unrestrictedUse
- Licence: CC-BY

# TECHNICAL INFORMATION

- Resource type: lexicalConceptualResource
- Format: text/tsv
- Character Encoding: UTF-8
- Creation information:
  - creationMode: automatic
  - creationModeDetails: This glossary contains transfer entries for German-to-English, annotated with probabilities.
  - creationTool:
  - targetResourceNameURI: LT-Xfr toolset

# CONTENT INFORMATION

- Linguality: bilingual
- Language(s): German English

# RELEVANT REFERENCES AND OTHER INFORMATION

## Resource Documentation

- - documentUnstructured: PANACEA Report D5.6: Transfer Selection Support.

## Resource Creation Information

### Resource Creator(s):

- organizationInfo:

- organizationName: Linguatec GmbH
- organizationShortName: Linguatec GmbH
- communicationInfo:

- email: info@linguatec.de
- address: Gottfried-Keller-Str. 12
- zipCode: 81245
- city: Munich
- country: Germany
- telephoneNumber: +49 0 89 896664-0
- faxNumber: +49 0 89 88919933

### Resource Funding:

- projectName: PANACEA
- projectShortName: PANACEA
- fundingType: euFunds
- funder: European Union